@@ -180,13 +180,13 @@ bool DICOMImage::OpenFile(const char *path)
 	bool retValue = true;
 	unsigned long options = DCM_ORDERLITTLEENDIAN | DCM_FORMATCONVERSION | DCM_VRMASK;
 	
-	// Try opening it "old style", if it fails because it's PART10, do it that way
+	// Try opening as PART10, if it fails it's might be bcause it does not have
+	// a preable and the try it that way
 	
-	if ( DCM_OpenFile(path, options, &handle_) != DCM_NORMAL )
+	if ( DCM_OpenFile(path, options | DCM_PART10FILE, &handle_) != DCM_NORMAL )
 	{
 		DCM_CloseObject(&handle_);
 		COND_PopCondition(TRUE);
-		options |= DCM_PART10FILE;
 		
 		if ( DCM_OpenFile(path, options, &handle_) != DCM_NORMAL )
 			retValue = false;
