@@ -1,4 +1,4 @@
-#define VERSION "2.28.15"
+#define VERSION "2.29.1"
 
 //****************************************************************************
 //
@@ -419,10 +419,10 @@ void StoreImageFiles(vector<string> &dicomFiles, SERIESMAP &seriesMap, char *out
 
 			int imgNum = dcmImg->ImageNumber();
 
-			// The acquisition number can come directly from the header or
+			// The qcquisition number can be provided by the user or
 			// If the number of slices greater than 1, use them to compute it.
 			// Else, if the echo number is greater than 0 use that (+1)
-			// Finally it can be computed from the parameter given by the user
+			// Finally it can come directly from the header
 			
 			int acqNum = 0;
 			if ( opts.numSlices > 0 )
@@ -442,7 +442,6 @@ void StoreImageFiles(vector<string> &dicomFiles, SERIESMAP &seriesMap, char *out
 
 			// Try to determine if the acquisition number makes sense
 
-			
 			IMAGELIST *timePoint = si.imageMap[acqNum];
 			if (timePoint == NULL)
 			{
@@ -531,10 +530,60 @@ void StoreImageFiles(vector<string> &dicomFiles, SERIESMAP &seriesMap, char *out
 	// do not increment the iterator here as this has to be handled conditionally at the end
 	for (SERIESMAP::iterator series = seriesMap.begin(); series != seriesMap.end(); )
 	{
+		SeriesInfo si = series->second;
+
+		// Loop through images in each list and verify if number of images is
+		// consistent, otherwise we need to split them in more lists
+
+		std::map<int, bool> fixMap;
+		
+		for ( IMAGEMAP::iterator timeIter = si.imageMap.begin(); timeIter != si.imageMap.end(); ++timeIter )
+		{
+			if ( ! si.mosaic )
+			{
+				int acqNum = timeIter->first;
+				IMAGELIST *timePointList = timeIter->second;
+				fixMap[acqNum] = timePointList->size() != timePointList->front().NumSlices();
+			}
+		}
+
+		for ( std::map<int, bool>::iterator fixIter = fixMap.begin(); fixIter != fixMap.end(); ++fixIter )
+		{
+			if ( fixIter->second )
+			{
+				// We need to fix this list. Use echo number to augment list size.
+
+				IMAGELIST *timePointList = si.imageMap[fixIter->first];
+				int baseAcqNum = fixIter->first;
+				
+				for ( IMAGELIST::iterator timeIter = timePointList->begin(); timeIter != timePointList->end(); )
+				{
+					// Acquisition numbers start from 1, while echo start from 0
+					int thisAcqNum = timeIter->ACQEchoNumber();
+					
+					if ( ++thisAcqNum != baseAcqNum )
+					{
+						// This has to go in a new list, see if we need to create it.
+
+						IMAGELIST *timePoint = si.imageMap[thisAcqNum];
+						if ( timePoint == NULL )
+						{
+							si.imageMap[thisAcqNum] = timePoint = new IMAGELIST;
+							if ( thisAcqNum > si.maxAcqNum ) si.maxAcqNum = thisAcqNum;
+						}
+						timePoint->push_back(*timeIter);
+						timePointList->erase(timeIter++);
+					}
+					else
+						++timeIter;
+				}
+				series->second = si;
+			}
+		}
+		
 		// For each series, check the number of groups (first image in first
 		// time point is sufficient)
 
-		SeriesInfo si = series->second;
 		IMAGEMAP fullImageMap = si.imageMap;
 		IMAGEMAP::iterator fimIter = fullImageMap.begin();
 		IMAGELIST *firstTimePoint = fimIter->second;
